package com.admin.major.mapper;

import java.util.List;
import com.admin.major.domain.MajorInfo;

/**
 * 专业管理Mapper接口
 * 
 * @author zewei
 * @date 2022-03-25
 */
public interface MajorInfoMapper 
{
    /**
     * 查询专业管理
     * 
     * @param majorId 专业管理主键
     * @return 专业管理
     */
    public MajorInfo selectMajorInfoByMajorId(String majorId);

    /**
     * 查询专业管理列表
     * 
     * @param majorInfo 专业管理
     * @return 专业管理集合
     */
    public List<MajorInfo> selectMajorInfoList(MajorInfo majorInfo);

    /**
     * 新增专业管理
     * 
     * @param majorInfo 专业管理
     * @return 结果
     */
    public int insertMajorInfo(MajorInfo majorInfo);

    /**
     * 新增或修改专业管理
     *
     * @param majorInfo 专业管理
     * @return 结果
     */
    public int replaceMajorInfo(MajorInfo majorInfo);

    /**
     * 修改专业管理
     * 
     * @param majorInfo 专业管理
     * @return 结果
     */
    public int updateMajorInfo(MajorInfo majorInfo);

    /**
     * 删除专业管理
     * 
     * @param majorId 专业管理主键
     * @return 结果
     */
    public int deleteMajorInfoByMajorId(String majorId);

    /**
     * 批量删除专业管理
     * 
     * @param majorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMajorInfoByMajorIds(String[] majorIds);
}
